import { EventEmitter } from '@angular/core';
import { SkyErrorModalService } from '@skyux/errors';
import { SkyFileDropChange, SkyFileItem, SkyFileSizePipe } from '@skyux/forms';
import { SkyLibResourcesService } from '@skyux/i18n';
import { Observable } from 'rxjs';
import { SkyAvatarSize } from './avatar-size';
import { SkyAvatarSrc } from './avatar-src';
import * as i0 from "@angular/core";
export declare class SkyAvatarComponent {
    #private;
    /**
     * Whether users can change the image. To select a different image,
     * users click the image or drag another image on top of it,
     * much like the `sky-file-drop` component in the
     * [file attachment module](https://developer.blackbaud.com/skyux/components/file-attachments/file-attachment).
     * @default false
     */
    set canChange(value: boolean | undefined);
    get canChange(): boolean;
    /**
     * The name of the record that the avatar represents.
     * If the `src` property does not specify an image, the component displays
     * initials from the first and last words in the name. To ensure
     * that the component extracts the correct initials, specify a name with no prefix
     * or suffix, or just specify initials with a space between them. This property is
     * not required, but the component requires either the `name` or `src` property.
     */
    set name(value: string | undefined);
    get name(): string | undefined;
    /**
     * The image to identify a record. This property is
     * not required, but the component requires either the `name` or `src` property.
     */
    set src(value: SkyAvatarSrc | undefined);
    get src(): SkyAvatarSrc | undefined;
    /**
     * The maximum file size for the image in bytes.
     * @default 512000 bytes
     */
    maxFileSize: number | undefined;
    /**
     * The size of the avatar.
     * Acceptable values are: `"small"`, `"medium"`, and `"large"`.
     * @default "large"
     */
    size: SkyAvatarSize | undefined;
    /**
     * Emits a `SkyFileItem` object when the image is updated.
     */
    avatarChanged: EventEmitter<SkyFileItem>;
    protected sizeDefault: Observable<SkyAvatarSize> | undefined;
    constructor(errorService: SkyErrorModalService, fileSizePipe: SkyFileSizePipe, resourcesService: SkyLibResourcesService);
    photoDrop(result: SkyFileDropChange): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyAvatarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyAvatarComponent, "sky-avatar", never, { "canChange": { "alias": "canChange"; "required": false; }; "name": { "alias": "name"; "required": false; }; "src": { "alias": "src"; "required": false; }; "maxFileSize": { "alias": "maxFileSize"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, { "avatarChanged": "avatarChanged"; }, never, never, false, never>;
}
