import { HarnessPredicate } from '@angular/cdk/testing';
import { SkyComponentHarness } from '@skyux/core/testing';
import { SkyAvatarHarnessFilters } from './avatar-harness-filters';
/**
 * Harness for interacting with an avatar component in tests.
 */
export declare class SkyAvatarHarness extends SkyComponentHarness {
    #private;
    /**
     * @internal
     */
    static hostSelector: string;
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyAvatarHarness` that meets certain criteria.
     */
    static with(filters: SkyAvatarHarnessFilters): HarnessPredicate<SkyAvatarHarness>;
    /**
     * Gets the initials displayed when no image URL is specified.
     */
    getInitials(): Promise<string | undefined>;
    /**
     * Gets the avatar's current image URL or Blob.
     */
    getSrc(): Promise<string | Blob | undefined>;
    /**
     * Gets whether users can change the image.
     */
    getCanChange(): Promise<boolean>;
    /**
     * Simulates the user selecting or dropping an image onto the component.
     */
    dropAvatarFile(file: File, waitForChange?: boolean): Promise<void>;
    /**
     * Gets whether an error indicating an invalid file type is displayed.
     */
    hasFileTypeError(): Promise<boolean>;
    /**
     * Gets whether an error indicating an invalid file size is displayed.
     */
    hasMaxSizeError(): Promise<boolean>;
    /**
     * Closes the currently displayed error.
     */
    closeError(): Promise<void>;
}
